autowisp.multiprocessing_util module — AutoWISP documentation

# autowisp.multiprocessing_util module

## Class Inheritance Diagram

Functions used by multiple bayesian sampling scripts.

autowisp.multiprocessing_util.get_code_version_str()

  Return a string identifying the version of the code being used.

autowisp.multiprocessing_util.get_log_outerr_filenames(existing_pid=False, **config)

  Return the filenames where setup_process() redirects log and output.

autowisp.multiprocessing_util.setup_process(**config)

  Logging and I/O setup for the current processes.

  Args (keyword only):
    std_out_err_fname(str): Format string for the standard output/error

      file name with substitutions including any keyword arguments passed to this function, `now` which gets replaced by current date/time, `pid` which gets replaced by the process ID, `task` which gets the value `'calculate'` by default but can be overwritten here.

    logging_fname(str): Format string for the logging file name (see

      `std_out_err_fname`).

    fname_datetime_format(str): The format for the date and time string

      to be inserted in the file names.

    logging_message_format(str): The format for the logging messages (see

      logging module documentation)

    logging_verbosity(str): The verbosity of logging (see logging module

      documentation)

    All other keyword arguments are used to substitute into the format

      strings for the filenames.

  Returns:

    None

autowisp.multiprocessing_util.setup_process_map(config)

  Like setup_process, but more convenient for multiprocessing.Pool.